@@ -28,7 +28,7 @@ from vdsm.network import driverloader
 from vdsm.network.link.iface import iface
 from vdsm.network.netlink import waitfor
 
-from .speed import speed
+from .bond_speed import speed
 
 speed
 
